%This is a Matlab script developed by Konstantinos Glynis
%based on the analysis of (https://www.itia.ntua.gr/el/docinfo/2079/)
%K. Glynis, T. Iliopoulou, P. Dimitriadis, and D. Koutsoyiannis, Stochastic investigation 
%of daily air temperature extremes from a global ground station network
%Input: a list with the stations names (C) and the individual station timeseries from GHCND.
%Output: a 2D array with the number of "suitable" records for every year. Please see the publication for the exact definition of "suitability"

clc; clear all; close all; tic;

load('Tavg_stations.mat'); C = Tavg_stations; clear Tavg_stations;
imax = length(C);
A = NaN(imax,2);

for i=1:imax;
    load(strcat('NOAA_GHCND_TAVG/',string(C(i))));
    n=numel(S(:,4));
    if n > 0;
        if S(1,1) < 1881;
            if n > 10958;
            dummy = find(S(:,1)>=1881,1);
            S = S(dummy:end,:);
            n=numel(S(:,4));
            end
        end
        clear years
        years = S(n,1)-S(1,1)+1;
        S = new_cleaning(Q,S);
        if S(1,1) <= 1935;
           if and(and(years >= 30,years <= inf),and(n/365.25 >= 30,n/365.25 <= inf));
               A(i,1) = S(1,1);
               A(i,2) = S(end,1);
           end
        end
    end
end

year = min(A(:,1)):max(A(:,2));
jmax = length(year);
B = NaN(jmax,2);
B(:,1) = year';
for j = 1:jmax;
    B(j,2) = sum(A(:,1)<=year(j))-sum(A(:,2)<=year(j));
end

filename = 'Tavg_Record_Availability.xlsx';
sheet = 1;
xlRange = 'A1';
xlswrite(filename,B,sheet,xlRange);

toc;